.. pyzome documentation master file, created by
   sphinx-quickstart on Fri Feb 10 22:10:54 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

==================================
Welcome to pyzome's documentation!
==================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   install
   intro
   basic
   zonal_waves
   qglogp
   tem
   mock_data 
   recipes

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
